package core.api.models.timemanager.tasks;

import core.api.models.timemanager.taskgroup.TaskgroupEntityInfo;
import core.entities.timemanager.Task;
import core.services.TaskSeriesService;

import java.time.LocalDate;

public class TaskEntityInfo {

    private long taskID;
    private String taskName;

    private int eta;

    private LocalDate startDate;

    private LocalDate deadline;

    private boolean overdue;

    private boolean finished;

    private int workTime;

    private boolean finishable;

    private boolean hasActiveSchedules;

    private boolean hasPlannedSchedules;
    private boolean hasTaskSerie;

    public TaskEntityInfo(Task task) {
        this.taskID = task.getTaskID();
        if(task.getTaskSerieItem() != null) {
            this.taskName = TaskSeriesService.insertNameIndex(task.getTaskSerieItem().getSeriesIndex(), task.getTaskName());
        } else {
            this.taskName = task.getTaskName();
        }
        this.eta = task.getEta();
        this.startDate = task.getStartDate();
        this.deadline = task.getDeadline();
        if(task.getDeadline() != null) {
            this.overdue = LocalDate.now().isAfter(task.getDeadline());
        }
        this.finished = task.isFinished();
        this.workTime = task.getWorkTime();
        this.finishable = task.isFinishable();
        this.hasActiveSchedules = task.hasActiveSchedule();
        this.hasPlannedSchedules = task.hasPlannedSchedules();
        this.hasTaskSerie = task.getTaskSerieItem() != null;
    }

    public long getTaskID() {
        return taskID;
    }

    public void setTaskID(long taskID) {
        this.taskID = taskID;
    }

    public String getTaskName() {
        return taskName;
    }

    public void setTaskName(String taskName) {
        this.taskName = taskName;
    }

    public int getEta() {
        return eta;
    }

    public void setEta(int eta) {
        this.eta = eta;
    }

    public LocalDate getStartDate() {
        return startDate;
    }

    public void setStartDate(LocalDate startDate) {
        this.startDate = startDate;
    }

    public LocalDate getDeadline() {
        return deadline;
    }

    public void setDeadline(LocalDate deadline) {
        this.deadline = deadline;
    }

    public boolean isOverdue() {
        return overdue;
    }

    public void setOverdue(boolean overdue) {
        this.overdue = overdue;
    }

    public boolean isFinished() {
        return finished;
    }

    public void setFinished(boolean finished) {
        this.finished = finished;
    }

    public int getWorkTime() {
        return workTime;
    }

    public void setWorkTime(int workTime) {
        this.workTime = workTime;
    }

    public boolean isFinishable() {
        return finishable;
    }

    public void setFinishable(boolean finishable) {
        this.finishable = finishable;
    }

    public boolean isHasActiveSchedules() {
        return hasActiveSchedules;
    }

    public void setHasActiveSchedules(boolean hasActiveSchedules) {
        this.hasActiveSchedules = hasActiveSchedules;
    }

    public boolean isHasPlannedSchedules() {
        return hasPlannedSchedules;
    }

    public void setHasPlannedSchedules(boolean hasPlannedSchedules) {
        this.hasPlannedSchedules = hasPlannedSchedules;
    }

    public boolean isHasTaskSerie() {
        return hasTaskSerie;
    }

    public void setHasTaskSerie(boolean hasTaskSerie) {
        this.hasTaskSerie = hasTaskSerie;
    }
}
