package core.entities.timemanager;

import core.api.models.timemanager.taskSchedule.scheduleInfos.BasicScheduleInfo;
import core.api.models.timemanager.taskSchedule.scheduleInfos.ScheduleInfo;
import core.api.models.timemanager.taskSchedule.scheduleInfos.ScheduleType;
import core.api.models.timemanager.taskgroup.TaskgroupEntityInfo;

import javax.persistence.*;
import java.time.LocalDate;
import java.time.LocalDateTime;
import java.util.List;

@Entity
@DiscriminatorValue("0")
public class BasicTaskSchedule extends AbstractSchedule{

   private LocalDate scheduleDate;

    public BasicTaskSchedule() {
    }

    public BasicTaskSchedule(Task task, LocalDateTime startTime, LocalDateTime stopTime, LocalDate scheduleDate) {
        super(task, startTime, stopTime);
        this.scheduleDate = scheduleDate;
    }

    public BasicTaskSchedule(Task task, LocalDateTime startTime) {
        super(task, startTime);
        this.scheduleDate = startTime.toLocalDate();
    }

    public BasicTaskSchedule(Task task, LocalDate scheduleDate) {
        super(task);
        this.scheduleDate = scheduleDate;
    }

    public LocalDate getScheduleDate() {
        return scheduleDate;
    }

    public void setScheduleDate(LocalDate scheduleDate) {
        this.scheduleDate = scheduleDate;
    }

    public ScheduleInfo toScheduleInfo() {
        int activeMinutes = calcActiveMinutes();
        List<TaskgroupEntityInfo> taskgroupEntityInfos = Taskgroup.getAncestorList(task.getTaskgroup()).stream().map(TaskgroupEntityInfo::new).toList();
        return new BasicScheduleInfo(scheduleID, ScheduleType.BASIC, startTime, stopTime, activeMinutes, task, taskgroupEntityInfos, scheduleDate);
    }

    @Override
    public boolean isMissed(LocalDateTime timeReference) {
        return startTime == null && scheduleDate.isBefore(timeReference.toLocalDate());
    }

    @Override
    public AbstractSchedule cloneSchedule() {
        return new BasicTaskSchedule(this.task,  this.scheduleDate);
    }

    @Override
    public void shiftSchedule(long numberDays) {
        this.scheduleDate = this.scheduleDate.plusDays(numberDays);
    }
}
